@@ -1,10 +1,24 @@
+'''Configuration value manipulation.'''
 import re
 
 
 def realize(v, item=None):
+    '''Makes objects contain concrete values from an item.
+
+    A silly example::
+
+        class AddExpression(object):
+            def realize(self, item):
+                return = item['x'] + item['y']
+
+        pipeline = Pipeline(ComputeMath(AddExpression()))
+
+    In the example, we want to compute an addition expression. The values
+    are defined in the Item.
+    '''
     if isinstance(v, dict):
         realized_dict = {}
-        for (key, value) in v.iteritems():
+        for (key, value) in v.items():
             realized_dict[key] = realize(value, item)
         return realized_dict
     elif isinstance(v, list):
@@ -16,6 +30,13 @@ def realize(v, item=None):
 
 
 class ConfigValue(object):
+    '''Configuration value validator.
+
+    The collection methods are useful for providing user configurable
+    settings at run time. For example, when a pipeline file is executed
+    by the warrior, the additional config values are presented in the
+    warrior configuration panel.
+    '''
     collector = None
 
     @classmethod
@@ -28,7 +49,8 @@ class ConfigValue(object):
         ConfigValue.collector = None
         return collected
 
-    def __init__(self, name, title="", description="", default=None, editable=True, advanced=True):
+    def __init__(self, name, title="", description="", default=None,
+                 editable=True, advanced=True):
         self.name = name
         self.title = title
         self.description = description
@@ -37,15 +59,15 @@ class ConfigValue(object):
         self.editable = editable
         self.advanced = advanced
 
-        if ConfigValue.collector != None:
+        if ConfigValue.collector is not None:
             ConfigValue.collector.append(self)
 
-    def realize(self, ignored):
+    def realize(self, dummy):
         return self.value
 
     def set_value(self, value):
         self.error = self.check_value(value)
-        if self.error == None:
+        if self.error is None:
             self.value = self.convert_value(value)
             return True
         else:
@@ -58,7 +80,7 @@ class ConfigValue(object):
         return value
 
     def is_valid(self):
-        return self.value != None
+        return self.value is not None
 
     def __str__(self):
         return "<" + self.name + ":" + str(self.value) + ">"
@@ -72,7 +94,7 @@ class StringConfigValue(ConfigValue):
         else:
             self.regex = None
 
-        ConfigValue.__init__(self, **kwargs)
+        ConfigValue.__init__(self, *args, **kwargs)
 
     def check_value(self, value):
         value = value.strip()
@@ -95,7 +117,7 @@ class NumberConfigValue(ConfigValue):
         else:
             self.max = None
 
-        ConfigValue.__init__(self, **kwargs)
+        ConfigValue.__init__(self, *args, **kwargs)
 
     def check_value(self, value):
         value = value.strip()
