@@ -1,7 +1,16 @@
+'''Actor model.'''
 # http://www.valuedlessons.com/2008/04/events-in-python.html
 
 
-class Event:
+class Event(object):
+    '''Lightweight event system.
+
+    Example::
+
+        my_event_system = Event()
+        my_event_system = my_listener_callback_function
+        my_event_system(my_event_data)
+    '''
     def __init__(self):
         self.handlers = set()
 
@@ -13,7 +22,8 @@ class Event:
         try:
             self.handlers.remove(handler)
         except:
-            raise ValueError("Handler is not handling this event, so cannot unhandle it.")
+            raise ValueError("Handler is not handling this event, "
+                             "so cannot unhandle it.")
         return self
 
     def fire(self, *args, **kargs):
